#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-eval-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-eval-plugin-2.3.0.0-GnHyFrFehnEBxaVS8IpMQg
key:                  hls-eval-plugin-2.3.0.0-GnHyFrFehnEBxaVS8IpMQg
license:              Apache-2.0
maintainer:
    https://github.com/haskell/haskell-language-server/contributors

author:
    https://github.com/haskell/haskell-language-server/contributors

synopsis:             Eval plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  44006cad0c75a53ff89920a088d72738
exposed:              True
exposed-modules:      Ide.Plugin.Eval Ide.Plugin.Eval.Types
hidden-modules:
    Ide.Plugin.Eval.Code Ide.Plugin.Eval.CodeLens
    Ide.Plugin.Eval.Config Ide.Plugin.Eval.GHC
    Ide.Plugin.Eval.Parse.Comments Ide.Plugin.Eval.Parse.Option
    Ide.Plugin.Eval.Rules Ide.Plugin.Eval.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-eval-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-eval-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-eval-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-eval-plugin
hs-libraries:         HShls-eval-plugin-2.3.0.0-GnHyFrFehnEBxaVS8IpMQg
depends:
    Diff-0.5-DbK2KXQffeb9yfLb5gceUe
    QuickCheck-2.15.0.1-Gvx9SMBV22v4z5c71KPTnf
    aeson-2.2.2.0-E8GnKqfyoqV8B1evVkUtMu base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    directory-1.3.8.5 dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    extra-1.7.16-zRgcudgyh3HVd3DrMjSx2 filepath-1.4.300.1 ghc-9.6.6
    ghc-boot-th-9.6.6 ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghcide-2.3.0.0-1NaRJpuXIo4LtkSTekOxmC
    hashable-1.4.7.0-IVKAR4D6WU9H8t6zzGQ76p
    hls-graph-2.3.0.0-HalSMp4zBFx6Mm7dJJkXUZ
    hls-plugin-api-2.3.0.0-9jhpQfOngSTGpS6BU5IF9H
    lens-5.3.4-FLE2Mpdc2NQ9IUFEHfSpBl
    lsp-2.2.0.0-BflLqOVRUEVJbJio8jNhrd
    lsp-types-2.0.2.0-4aQVjmLItHfKl5dggvyXyI
    megaparsec-9.7.0-LcQIYWb87vKBQkwIt8CBXH mtl-2.3.1
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
    pretty-simple-4.1.4.0-RC8yN5GskMCKpzemakI1b
    safe-exceptions-0.1.7.4-HBQwntg3aBlekG6UUSCWu text-2.0.2
    time-1.12.2 transformers-0.6.1.0
    unliftio-0.2.25.1-406ICvddDrs4REwMxxdvSj
    unordered-containers-0.2.20.1-FX7g4DMKoiaDV91wUmRzTu

haddock-interfaces:
    /usr/share/doc/haskell-hls-eval-plugin/html/hls-eval-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-eval-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

